@@ -8,14 +8,13 @@ use base "Template::Plugin";
 use Text::Greeking;
 use UNIVERSAL::require;
 
-our $VERSION = '0.0.2';
+our $VERSION = '1.0';
 
 sub new {
     my ($class, $context, $options) = @_;
     my $greeking_class = "Text::Greeking";
     $options ||= { lang => "en" };
     return sub {
-        require YAML;
         my $opt = { %$options, %{ $_[0] || {} } };
 
         if ($opt) {
